AMCP contains all of the data sets used in Maxwell, Delaney, & Kelley's (2027) Designing experiments and analyzing data: A model comparison perspective (4th edition). Information about the book is available at its companion website, https://designingexperiments.com.
Ken Kelley kkelley@nd.edu
Beginning with AMCP version 2.0, the package is tailored to the 4th edition of the book. If you want the data as distributed with the 3rd edition (Maxwell, Delaney, & Kelley, 2018), install the archived version (1.0.2) from CRAN, for example with remotes::install_version("AMCP", version = "1.0.2").
The general strategy is to have chapter data (e.g., from numeric examples) denoted by the chapter and table number,
such as chapter_1_table_1 (for Table 1 from Chapter 1). Alternatively, a chapter and table can be accessed by capital "C"
followed by the chapter number and capital "T" followed by the table number, as in C1T1 (for Table 1 from Chapter 1).
For the exercises at the end of the chapter, the general strategy is to denote the data sets as chapter_1_exercise_18 (for Exercise 18 from Chapter 1).
Also, an uppercase "C" and "E" can be used, as in Chapter_1_Exercise_18. Alternatively, the data from an exercise can be accessed by capital "C"
followed by the chapter number and capital "E" followed by the exercise number, as in C1E18 (for Exercise 18 from Chapter 1).
For a data set of interest to be loaded into the workspace, it must be loaded using the data() function as: data(chapter_1_table_1).
There are a few "one-off" naming conventions for non-standard data, such as raw data to produce the output shown in the book (e.g., data(chapter_3_table_7_raw)),
for the data from the Chapter 9 extension used in Exercise 1 (e.g., data("chapter_9_extension_exercise_1") or data("C9ExtE1")), data for the tutorial (e.g., data(tutorial_1_table_1) or data(T1T1)),
or the Chapter 15 Exercise 18 data in the "univariate" format (long, not wide; e.g., data("chapter_15_exercise_18_univariate") or data(C15E18U)).
A list of the available data sets from AMCP can be obtained with the following code: data(package="AMCP")
Note that, for many data sets the coding for factors is numeric. Correspondingly, those variables may need to be identified as factors (e.g., C16E9$Room <- as.factor(C16E9$Room)). Further,
the data sets are not always in the most convenient form for analysis, as they are generally entered to match the style in the book. Thus, for some analyses the data may benefit from being parsed, wrangled, or tidied.
See vignette("factors-and-coding", package = "AMCP") for recipes that add factor labels without changing the canonical data, and a worked example showing that relabeling reproduces the book's results.
We recommend the DMAR package as the companion for carrying out the book's analyses; install it with install.packages("DMAR"). The book itself illustrates these analyses using the MBESS package, which may be used as well.
Note that https://designingexperiments.com/computing/ shows R code (via R Markdown) for implementing many of the analyses in the book, by chapter.
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge. ISBN 978-1-041-25384-6.
See the web page that accompanies the book here: https://designingexperiments.com. The book is published by Routledge; its publisher page is https://www.routledge.com/Designing-Experiments-and-Analyzing-Data-A-Model-Comparison-Perspective/Maxwell-Delaney-Kelley/p/book/9781041253846.
For suggested updates, please email Ken Kelley (kkelley@nd.edu); see also https://kenkelley.org.
Useful links: