Learn R Programming

AMCP (version 2.0.0)

chapter_11_table_4: The data used in Chapter 11, Table 4

Description

The data used in Chapter 11, Table 4

Usage

data(chapter_11_table_4)

Arguments

Format

An object of class data.frame with 10 rows and 4 columns.

Variables

YCondition1

a numeric vector

YCondition2

a numeric vector

YCondition3

a numeric vector

YCondition4

a numeric vector

Synonym

C11T4

Author

Ken Kelley kkelley@nd.edu

Details

No analyses are conducted for this data set. The traditional view of a repeated-measures design is to regard it as a two-factor design. Specifically, one factor represents the repeated condition (e.g., time, drug, subtest), whereas the second factor represents subjects. The rationale for this conceptualization can be understood by considering the data in Table 11.4. When the data are displayed this way, the design looks very much like other factorial designs we've already encountered.

References

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_11_table_4)

# Or, alternatively load the data as
data(C11T4)

# View the structure
str(chapter_11_table_4)

Run the code above in your browser using DataLab