Learn R Programming

AMCP (version 2.0.0)

chapter_12_exercise_22: The data used in Chapter 12, Exercise 22

Description

Data from Chapter 12 Exercise 22 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). The Hu, Antony, Creery, Vargas, Bodenhausen, and Paller (2015) study of whether implicit social biases can be reduced during sleep. Forty participants were measured on implicit gender bias and implicit racial bias; during a nap, an auditory cue reactivated the counter-bias training for one of the two biases (the cued bias) but not the other (the uncued bias). The exercise analyzes the four bias scores as a 2 (cuing: cued, uncued) by 2 (time: prenap, postnap) fully within-subjects design; higher (more positive) scores reflect more bias.

Usage

data(chapter_12_exercise_22)

Arguments

Format

An object of class data.frame with 40 rows and 8 columns.

Variables

Sample

data collection: 1 = original sample, 2 = replication sample

CuedBiasType

the bias that was cued during the nap for this participant: Gender or Race (a between-subjects factor the exercise sets aside)

Cued_Baseline

cued-bias score at baseline

Uncued_Baseline

uncued-bias score at baseline

Cued_Prenap

cued-bias score before the nap

Cued_Postnap

cued-bias score after the nap

Uncued_Prenap

uncued-bias score before the nap

Uncued_Postnap

uncued-bias score after the nap

Synonym

C12E22

Author

Ken Kelley kkelley@nd.edu

References

Hu, X., Antony, J. W., Creery, J. D., Vargas, I. M., Bodenhausen, G. V., & Paller, K. A. (2015). Unlearning implicit social biases during sleep. Science, 348, 1013--1015.

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_12_exercise_22)

# Or, alternatively load the data as
data(C12E22)

# View the structure
str(chapter_12_exercise_22)

# Brief summary of the data.
summary(chapter_12_exercise_22)

Run the code above in your browser using DataLab