Learn R Programming

AMCP (version 2.0.0)

chapter_12_exercise_23: The data used in Chapter 12, Exercise 23

Description

Data from Chapter 12 Exercise 23 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). The one-week follow-up to the Hu et al. (2015) sleep study of Exercise 22, adding a delayed measurement so that each participant now has six bias scores (cued and uncued, at prenap, postnap, and one-week delayed). Two of the 40 participants lacked delayed scores, so this data set has 38 rows. The exercise analyzes the scores as a 2 (cuing) by 3 (time) fully within-subjects design; lower scores indicate less bias.

Usage

data(chapter_12_exercise_23)

Arguments

Format

An object of class data.frame with 38 rows and 10 columns.

Variables

Sample

data collection: 1 = original sample, 2 = replication sample

CuedBiasType

the bias that was cued during the nap: Gender or Race

Cued_Baseline

cued-bias score at baseline

Uncued_Baseline

uncued-bias score at baseline

Cued_Prenap

cued-bias score before the nap

Cued_Postnap

cued-bias score after the nap

Cued_Delayed

cued-bias score at the one-week follow-up

Uncued_Prenap

uncued-bias score before the nap

Uncued_Postnap

uncued-bias score after the nap

Uncued_Delayed

uncued-bias score at the one-week follow-up

Synonym

C12E23

Author

Ken Kelley kkelley@nd.edu

References

Hu, X., Antony, J. W., Creery, J. D., Vargas, I. M., Bodenhausen, G. V., & Paller, K. A. (2015). Unlearning implicit social biases during sleep. Science, 348, 1013--1015.

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_12_exercise_23)

# Or, alternatively load the data as
data(C12E23)

# View the structure
str(chapter_12_exercise_23)

# Brief summary of the data.
summary(chapter_12_exercise_23)

Run the code above in your browser using DataLab