Learn R Programming

AMCP (version 2.0.0)

chapter_12_exercise_24: The data used in Chapter 12, Exercise 24

Description

Data from Chapter 12 Exercise 24 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). The Carnes, Lickel, and Janoff-Bulman (2015) study of how social contexts shape beliefs about moral principles. Each of 118 participants rated the importance of six moral principles in each of four social contexts, giving 24 ratings per participant, each on a scale from 1 (not at all important) to 9 (extremely important). Variables are named PRINCIPLE_CONTEXT, where the principle is CARE, FAIR, LOYA, AUTH, PURE, or JUST and the context is SOC (social category), TAS (task group), INT (intimacy group), or LOO (loose association).

Usage

data(chapter_12_exercise_24)

Arguments

Format

An object of class data.frame with 118 rows and 25 columns.

Variables

ID

participant identifier

CARE_SOC

Care, rated in the social category context

CARE_TAS

Care, rated in the task group context

CARE_INT

Care, rated in the intimacy group context

CARE_LOO

Care, rated in the loose association context

FAIR_SOC

Fairness, rated in the social category context

FAIR_TAS

Fairness, rated in the task group context

FAIR_INT

Fairness, rated in the intimacy group context

FAIR_LOO

Fairness, rated in the loose association context

LOYA_SOC

Loyalty, rated in the social category context

LOYA_TAS

Loyalty, rated in the task group context

LOYA_INT

Loyalty, rated in the intimacy group context

LOYA_LOO

Loyalty, rated in the loose association context

AUTH_SOC

Authority, rated in the social category context

AUTH_TAS

Authority, rated in the task group context

AUTH_INT

Authority, rated in the intimacy group context

AUTH_LOO

Authority, rated in the loose association context

PURE_SOC

Purity, rated in the social category context

PURE_TAS

Purity, rated in the task group context

PURE_INT

Purity, rated in the intimacy group context

PURE_LOO

Purity, rated in the loose association context

JUST_SOC

Justice, rated in the social category context

JUST_TAS

Justice, rated in the task group context

JUST_INT

Justice, rated in the intimacy group context

JUST_LOO

Justice, rated in the loose association context

Synonym

C12E24

Author

Ken Kelley kkelley@nd.edu

References

Carnes, N. C., Lickel, B., & Janoff-Bulman, R. (2015). Shared perceptions: Morality is embedded in social contexts. Personality and Social Psychology Bulletin, 41, 351--362.

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_12_exercise_24)

# Or, alternatively load the data as
data(C12E24)

# View the structure
str(chapter_12_exercise_24)

# Brief summary of the data.
summary(chapter_12_exercise_24)

Run the code above in your browser using DataLab