Learn R Programming

AMCP (version 2.0.0)

chapter_12_exercise_26: The data used in Chapter 12, Exercise 26

Description

Data from Chapter 12 Exercise 26 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). The Gibson, Radvansky, Johnson, and McNerney (2012) study of whether grapheme-color synesthetes have better memory for word lists than nonsynesthetes. Lists of high-frequency or low-frequency words were presented to 48 nonsynesthetes and 10 synesthetes, and two dependent variables were measured for each word frequency: input-output (IO) correspondence and recall accuracy.

Usage

data(chapter_12_exercise_26)

Arguments

Format

An object of class data.frame with 58 rows and 6 columns.

Variables

ID

participant identifier

Group

0 = nonsynesthete (control), 1 = grapheme-color synesthete

HFcorr

input-output correspondence for high-frequency words, a proportion measuring the extent to which temporal order was preserved in recall (higher scores reflect greater use of relational cues)

LFcorr

input-output correspondence for low-frequency words

HFrecall

recall accuracy for high-frequency words (higher scores reflect higher accuracy)

LFrecall

recall accuracy for low-frequency words

Synonym

C12E26

Author

Ken Kelley kkelley@nd.edu

References

Gibson, B. S., Radvansky, G. A., Johnson, A. C., & McNerney, M. W. (2012). Grapheme-color synesthesia can enhance immediate memory without disrupting the encoding of relational cues. Psychonomic Bulletin & Review, 19, 1172--1177.

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_12_exercise_26)

# Or, alternatively load the data as
data(C12E26)

# View the structure
str(chapter_12_exercise_26)

# Brief summary of the data.
summary(chapter_12_exercise_26)

Run the code above in your browser using DataLab