Learn R Programming

AMCP (version 2.0.0)

chapter_12_exercise_27: The data used in Chapter 12, Exercise 27

Description

Data from Chapter 12 Exercise 27 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). Reports of the number of negative life events collected from three members (mother, father, and child) of 95 first-marriage nuclear families and 98 stepfamilies, as described by Bray and Maxwell (1995). Family member is a within-subjects factor and type of family is a between-subjects factor.

Usage

data(chapter_12_exercise_27)

Arguments

Format

An object of class data.frame with 193 rows and 6 columns.

Variables

id

family identifier

grp

type of family: 1 = nuclear family, 2 = stepfamily

sex

sex of the child: 1 = boy, 2 = girl

mtb

number of negative life events reported by the mother

ftb

number of negative life events reported by the father

ctb

number of negative life events reported by the child

Synonym

C12E27

Author

Ken Kelley kkelley@nd.edu

References

Bray, J. H., & Maxwell, S. E. (1995). Multivariate statistics for family psychology research. Journal of Family Psychology, 9, 144--160.

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_12_exercise_27)

# Or, alternatively load the data as
data(C12E27)

# View the structure
str(chapter_12_exercise_27)

# Brief summary of the data.
summary(chapter_12_exercise_27)

Run the code above in your browser using DataLab