Learn R Programming

AMCP (version 2.0.0)

chapter_14_table_5: The data used in Chapter 14, Table 5

Description

The data used in Chapter 14, Table 5

Usage

data(chapter_14_table_5)

Arguments

Format

An object of class data.frame with 10 rows and 5 columns.

Variables

D1

participant D1 variable

D2

participant D2 variable

D3

participant D3 variable

D4

participant D4 variable

D5

participant D5 variable

Synonym

C14T5

Author

Ken Kelley kkelley@nd.edu

Details

In terms of symbols, let D(1i) represent the linear trend for a given angle. For the hypothetical data contained in Table 14.4, Table 14.5 gives an appropriate and substantively interesting set of D variables. The D variables (rather than the raw data itself) is used because of the benefits and flexibility gained from analyzing the D variables directly (rather than indirectly as we did with the Table 14.4 data).

References

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_14_table_5)

# Or, alternatively load the data as
data(C14T5)

# View the structure
str(chapter_14_table_5)

Run the code above in your browser using DataLab