Learn R Programming

AMCP (version 2.0.0)

chapter_14_table_9: The data used in Chapter 14, Table 9

Description

The data used in Chapter 14, Table 9

Usage

data(chapter_14_table_9)

Arguments

Format

An object of class data.frame with 20 rows and 4 columns.

Variables

Angle0

participant reaction time at angle 0

Angle4

participant reaction time at angle 4

Angle8

participant reaction time at angle 8

Group

participant age (young or old)

Synonym

C14T9

Author

Ken Kelley kkelley@nd.edu

Details

These data are identical to those analyzed in chapter 12 (see Tables 12.7 and 12.15) to facilitate comparisons of the multivariate approach and the mixed-model approach.The hypothetical data contained in Table 14.9 contains an additional level of angle (four degrees) that was not considered in Table 14.7.

References

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_14_table_9)

# Or, alternatively load the data as
data(C14T9)

# View the structure
str(chapter_14_table_9)

Run the code above in your browser using DataLab