The first table in Chapter 15 presents the Hypothetical McCarthy data again (originally shown in Table 11.5). This data set is used throughout the chapter to illustrate the discussion given on the mixed model.
References
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data:
A model comparison perspective (4th ed.). New York, NY: Routledge.