Learn R Programming

AMCP (version 2.0.0)

chapter_4_exercise_18: The data used in Chapter 4, Exercise 18

Description

Data from Chapter 4 Exercise 18 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). Posttest scores on a fear scale for four treatments for agoraphobia, with three subjects randomly assigned to each therapy; higher scores indicate more severe phobia.

Usage

data(chapter_4_exercise_18)

Arguments

Format

An object of class data.frame with 12 rows and 2 columns.

Variables

dv

posttest score on a fear scale (higher scores indicate more severe phobia)

cond

treatment: 1 = rational-emotive (R-E), 2 = psychoanalytic (P), 3 = client-centered (C-C), 4 = behavioral (B)

Synonym

C4E18

Author

Ken Kelley kkelley@nd.edu

References

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_4_exercise_18)

# Or, alternatively load the data as
data(C4E18)

# View the structure
str(chapter_4_exercise_18)

# Brief summary of the data.
summary(chapter_4_exercise_18)

Run the code above in your browser using DataLab