Learn R Programming

AMCP (version 2.0.0)

chapter_6_exercise_11: The data used in Chapter 6, Exercise 11

Description

Data from Chapter 6 Exercise 11 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). The mean number of incorrect turns made by rats learning a maze after exposure to one of four equally spaced dosage levels of a drug, with five animals per level. Because drug dosage is quantitative, these data are suited to trend analysis.

Usage

data(chapter_6_exercise_11)

Arguments

Format

An object of class data.frame with 20 rows and 2 columns.

Variables

Errors

mean number of incorrect turns made over five trials

Dosage

drug dosage level, equally spaced in units of size 1 (1, 2, 3, 4)

Synonym

C6E11

Author

Ken Kelley kkelley@nd.edu

References

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_6_exercise_11)

# Or, alternatively load the data as
data(C6E11)

# View the structure
str(chapter_6_exercise_11)

# Brief summary of the data.
summary(chapter_6_exercise_11)

Run the code above in your browser using DataLab