Learn R Programming

AMCP (version 2.0.0)

chapter_7_exercise_21: The data used in Chapter 7, Exercise 21

Description

Data from Chapter 7 Exercise 21 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). Trust scores in a 2 (gender) by 2 (drug) between-subjects factorial design in which 20 females and 20 males were randomly assigned to receive either oxytocin or a placebo; trust was measured in a variation of the prisoner's dilemma, and higher scores indicate more trust.

Usage

data(chapter_7_exercise_21)

Arguments

Format

An object of class data.frame with 40 rows and 3 columns.

Variables

Gender

1 = female, 2 = male

Drug

1 = oxytocin, 2 = placebo

Trust

trust score (higher scores indicate more trust)

Synonym

C7E21

Author

Ken Kelley kkelley@nd.edu

References

Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.

Examples

Run this code
# Load the data
data(chapter_7_exercise_21)

# Or, alternatively load the data as
data(C7E21)

# View the structure
str(chapter_7_exercise_21)

# Brief summary of the data.
summary(chapter_7_exercise_21)

Run the code above in your browser using DataLab