Data from Chapter 12 Exercise 24 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). The Carnes, Lickel, and Janoff-Bulman (2015) study of how social contexts shape beliefs about moral principles. Each of 118 participants rated the importance of six moral principles in each of four social contexts, giving 24 ratings per participant, each on a scale from 1 (not at all important) to 9 (extremely important). Variables are named PRINCIPLE_CONTEXT, where the principle is CARE, FAIR, LOYA, AUTH, PURE, or JUST and the context is SOC (social category), TAS (task group), INT (intimacy group), or LOO (loose association).
data(chapter_12_exercise_24)An object of class data.frame with 118 rows and 25 columns.
participant identifier
Care, rated in the social category context
Care, rated in the task group context
Care, rated in the intimacy group context
Care, rated in the loose association context
Fairness, rated in the social category context
Fairness, rated in the task group context
Fairness, rated in the intimacy group context
Fairness, rated in the loose association context
Loyalty, rated in the social category context
Loyalty, rated in the task group context
Loyalty, rated in the intimacy group context
Loyalty, rated in the loose association context
Authority, rated in the social category context
Authority, rated in the task group context
Authority, rated in the intimacy group context
Authority, rated in the loose association context
Purity, rated in the social category context
Purity, rated in the task group context
Purity, rated in the intimacy group context
Purity, rated in the loose association context
Justice, rated in the social category context
Justice, rated in the task group context
Justice, rated in the intimacy group context
Justice, rated in the loose association context
C12E24
Ken Kelley kkelley@nd.edu
Carnes, N. C., Lickel, B., & Janoff-Bulman, R. (2015). Shared perceptions: Morality is embedded in social contexts. Personality and Social Psychology Bulletin, 41, 351--362.
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). New York, NY: Routledge.
# Load the data
data(chapter_12_exercise_24)
# Or, alternatively load the data as
data(C12E24)
# View the structure
str(chapter_12_exercise_24)
# Brief summary of the data.
summary(chapter_12_exercise_24)
Run the code above in your browser using DataLab