chapter_13_table_5: The data used in Chapter 13, Table 5
Description
Data from Table 13.5 of Designing Experiments and Analyzing Data: A Model Comparison Perspective (4th edition; Maxwell, Delaney, & Kelley). Two sets of hypothetical data, each consisting of two \(D\) (difference) variables, used to illustrate how a determinant reflects generalized variance.
Usage
data(chapter_13_table_5)
Arguments
Format
An object of class data.frame with 14 rows and 4 columns.
Variables
SetA_D1
first D variable for data set (a)
SetA_D2
second D variable for data set (a)
SetB_D1
first D variable for data set (b); identical to SetA_D1
SetB_D2
second D variable for data set (b); the same values as SetA_D2 but paired with different D1 scores
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data:
A model comparison perspective (4th ed.). New York, NY: Routledge.
# Load the datadata(chapter_13_table_5)
# Or, alternatively load the data asdata(C13T5)
# View the structurestr(chapter_13_table_5)
# Brief summary of the data.summary(chapter_13_table_5)