Chapter 14 introduces longitudinal randomized designs with a hypothetical study of 100 participants, 44 of whom were randomly assigned to an active treatment condition and 56 of whom were assigned to a control group. The outcome variable is measured at baseline (time 0) and at two post-intervention occasions (times 4 and 8). Table 14.13 presents the sample means by group and time, and Table 14.14 presents the tests of the omnibus effects for these data. The same data set is analyzed with mixed-effects models in Chapter 15 (see Tables 15.15 and 15.16). The data are stored in the long ("univariate") format expected by the mixed-effects code shown in Chapter 15, with one row per participant per measurement occasion.
References
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data:
A model comparison perspective (4th ed.). New York, NY: Routledge.